==> haskell-parser-combinators-1.3.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parser-combinators
version:              1.3.0
visibility:           public
id:                   parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
key:                  parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Mark Karpov <markkarpov92@gmail.com>
    Alex Washburn <github@recursion.ninja>

homepage:             https://github.com/mrkkrp/parser-combinators
synopsis:
    Lightweight package providing commonly useful parser combinators

description:
    Lightweight package providing commonly useful parser combinators.

category:             Parsing
abi:                  e37714cb88628655fcd89d2ddc29c60a
exposed:              True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
    Control.Monad.Permutations

import-dirs:          /usr/lib/ghc-9.6.6/site-local/parser-combinators-1.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/parser-combinators-1.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/parser-combinators-1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parser-combinators
hs-libraries:         HSparser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock

haddock-html:         /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parser-combinators-1.3.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parser-combinators
version:              1.3.1
visibility:           public
id:                   parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
key:                  parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Mark Karpov <markkarpov92@gmail.com>
    Alex Washburn <github@recursion.ninja>

homepage:             https://github.com/mrkkrp/parser-combinators
synopsis:
    Lightweight package providing commonly useful parser combinators

description:
    Lightweight package providing commonly useful parser combinators.

category:             Parsing
abi:                  2638e33b69db634bd09d5298c4954a33
exposed:              True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
    Control.Monad.Permutations

import-dirs:          /usr/lib/ghc-9.6.6/site-local/parser-combinators-1.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/parser-combinators-1.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/parser-combinators-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parser-combinators
hs-libraries:         HSparser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock

haddock-html:         /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
